#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-EJqunhwFIWV4RhfcvedLlD
key:                  haskell-language-server-2.3.0.0-EJqunhwFIWV4RhfcvedLlD
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  8dc6dceb9b9f0f0cf1d34c38b92ab849
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-EJqunhwFIWV4RhfcvedLlD
depends:
    aeson-pretty-0.8.10-HqzFRMIxciYK7th9EgJP2r
    async-2.2.6-IXER6sJdc7YHGmcgizEodd base-4.18.2.1
    base16-bytestring-1.0.2.0-LrPjj1dxETchTztOr2OJt bytestring-0.11.5.3
    containers-0.6.7 cryptohash-sha1-0.11.101.0-HI6pL8D37DP2FUDljp91kB
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-2PWm640KjWzJS4LkjIyaan filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-Hlz9iyA0QZeAnSORZKavOy
    githash-0.1.6.3-1RD7pFybUwrKyk7ghLInxC
    hie-bios-0.12.0-4FJCiykFtjs4mUTZd5sGER
    hiedb-0.4.3.0-3ay8FjQp08VCDJR4vqwC7b
    hls-alternate-number-format-plugin-2.3.0.0-Dq17W2lQsPqIM7MRxjZPg4
    hls-cabal-fmt-plugin-2.3.0.0-raq9POffgaA2do21AMwuq
    hls-cabal-plugin-2.3.0.0-IdUvM5EpQZ7AvQ9BTZHTp9
    hls-call-hierarchy-plugin-2.3.0.0-HE6ddhwHwEXCUFPE5xWhn2
    hls-change-type-signature-plugin-2.3.0.0-L4OjORTY6XRC6pxfPuPgAJ
    hls-class-plugin-2.3.0.0-IXPvZxDDCBH6KPIndGltJo
    hls-code-range-plugin-2.3.0.0-1RVxZI8KYkW6lqVRArdFaq
    hls-eval-plugin-2.3.0.0-7f81zrbMZvSGCssl8zw4HT
    hls-explicit-fixity-plugin-2.3.0.0-Ib5mnS7zbnk7Rk0XUIbSvy
    hls-explicit-imports-plugin-2.3.0.0-JhJq05f3Wwc3x0dul6ZGHF
    hls-explicit-record-fields-plugin-2.3.0.0-EuRCeuvdtZ63onETlt3I9P
    hls-fourmolu-plugin-2.3.0.0-JtX1WIMLTUv9BcPOJiue0q
    hls-gadt-plugin-2.3.0.0-F51RIDg7j6hEEeV5oXHIeN
    hls-graph-2.3.0.0-49SURZyYUZU60vKjBpDemp
    hls-hlint-plugin-2.3.0.0-7jDTMkdydF43HM04nDKZcY
    hls-module-name-plugin-2.3.0.0-2b2ww607y636JB0TtvCfjd
    hls-ormolu-plugin-2.3.0.0-4AJoXFwxWl5LUrov677Gzp
    hls-overloaded-record-dot-plugin-2.3.0.0-Hp3QLf8cYUWFPoWYAWZ03I
    hls-plugin-api-2.3.0.0-88NH5yynXbj514QpGYzYb8
    hls-pragmas-plugin-2.3.0.0-EQiCplcUIg5C61p4eXgfFf
    hls-qualify-imported-names-plugin-2.3.0.0-969AZgaPbzsKXXRAyovtcI
    hls-refactor-plugin-2.3.0.0-pOL4RQpVhyKUcHuEsH4aF
    hls-rename-plugin-2.3.0.0-6uvP0gZTPvi7ZiJ2Kh9A2r
    hls-retrie-plugin-2.3.0.0-J6iq2WJFUj8IiV6Z8Fo2Da
    hls-splice-plugin-2.3.0.0-EqyBAwXpnCu6ihbLdc5VMB
    hls-stylish-haskell-plugin-2.3.0.0-8oUULNNFNCFFp2N9rOjcK3
    lsp-2.2.0.0-HVGkLd1F33cFThbkDgpmo4
    optparse-applicative-0.18.1.0-2rPuK6RlcjABfxn2Xjogoz
    optparse-simple-0.1.1.4-1FltSFulP8uFkNdHnmVZfJ
    prettyprinter-1.7.1-2S4HQegaAhI5MUy2otn1KM process-1.6.19.0
    safe-exceptions-0.1.7.4-GGuoYnXnneqGBM7Qcu1Pau
    sqlite-simple-0.4.19.0-8nPUAhv5QId14VmPiR3ufh text-2.0.2
    unordered-containers-0.2.20.1-2gLa11KPU9tAOCQUon3yBM

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

